<?php

/**
 * General editor interface of Codeeditor_XH.
 *
 * Copyright (c) 2011-2012 Christoph M. Becker (see license.txt)
 */
 

// utf-8-marker: äöüß


if (!defined('CMSIMPLE_XH_VERSION')) {
    header('HTTP/1.0 403 Forbidden');
    exit;
}


/**
 * Returns the configuration in JSON.
 *
 * @return string
 */
function codeeditor_config() {
    global $plugin_cf;
    
    $pcf = $plugin_cf['codeeditor'];
    
    return 'theme: \''.$pcf['theme'].'\','
	    .' indentUnit: '.$pcf['indent_unit'].','
	    .' tabSize: '.$pcf['tab_size'].','
	    .' indentWithTabs: '.($pcf['indent_with_tabs'] ? 'true' : 'false').','
	    .' tabMode: \''.$pcf['tab_mode'].'\','
	    .' electricChars: '.($pcf['electric_chars'] ? 'true' : 'false').','
	    .' extraKeys: {\'Esc\': CODEEDITOR.toggleFullscreen},'
	    .' lineWrapping: '.($pcf['line_wrapping'] ? 'true' : 'false').','
	    .' lineNumbers: '.($pcf['line_numbers'] ? 'true' : 'false').','
	    .' firstLineNumber: '.$pcf['first_line_number'].','
	    .' matchBrackets: '.($pcf['match_brackets'] ? 'true' : 'false').','
	    .' workTime: '.$pcf['work_time'].','
	    .' workDelay: '.$pcf['work_delay'].','
	    .' onFocus: CODEEDITOR.onFocus,'
	    .' undoDepth: '.$pcf['undo_depth'];
}


/**
 * Includes the editor's javascripts to the <head>.
 *
 * @global string $hjs
 * @return void
 */
function include_codeeditor() {
    global $hjs, $pth, $tx, $plugin_cf, $plugin_tx;
    static $again = FALSE;
    
    if ($again) {return;}
    
    $pcf = $plugin_cf['codeeditor'];
    $ptx = $plugin_tx['codeeditor'];
    $dir = $pth['folder']['plugins'].'codeeditor/';
    
    $hjs .= '<script type="text/javascript" src="'.$dir.'codemirror/lib/codemirror.js"></script>'."\n"
	    .tag('link rel="stylesheet" type="text/css" href="'.$dir.'codemirror/lib/codemirror.css"')."\n"
	    .'<script type="text/javascript" src="'.$dir.'codemirror/mode/css/css.js"></script>'."\n"
	    .'<script type="text/javascript" src="'.$dir.'codemirror/mode/xml/xml.js"></script>'."\n"
	    .'<script type="text/javascript" src="'.$dir.'codemirror/mode/javascript/javascript.js"></script>'."\n"
	    .'<script type="text/javascript" src="'.$dir.'codemirror/mode/php/php.js"></script>'."\n"
	    .'<script type="text/javascript" src="'.$dir.'codemirror/mode/clike/clike.js"></script>'."\n"
	    .'<script type="text/javascript" src="'.$dir.'codemirror/mode/htmlmixed/htmlmixed.js"></script>'."\n";
    $fn = $dir.'codemirror/theme/'.$pcf['theme'].'.css';
    if (is_readable($fn)) {
	$hjs .= tag('link rel="stylesheet" type="text/css" href="'.$fn.'"')."\n";
    }
    $hjs .= '<script type="text/javascript" src="'.$dir.'codeeditor.js"></script>'."\n"
	    .'<script type="text/javascript">'."\n".'/* <![CDATA[ */'."\n"
	    .'CODEEDITOR.text = {'."\n"
	    .'    save: \''.addcslashes(ucfirst($tx['action']['save']), "\0'\"\\\f\n\r\t\v").'\','."\n"
	    .'    confirmLeave: \''.addcslashes($ptx['confirm_leave'], "\0'\"\\\f\n\r\t\v").'\','."\n"
	    .'    noChanges: \''.addcslashes($ptx['no_changes'], "\0'\"\\\f\n\r\t\v").'\''."\n"
	    .'}'."\n"
	    .'/* ]]> */'."\n".'</script>'."\n";
}


/**
 * Returns JS to replace a textarea with an editor instance.
 *
 * @param string $id  The textarea's ID.
 * @param string $config  The editor's configuration in JSON.
 * @return string
 */
function codeeditor_replace($id, $config = '') {
    return <<<SCRIPT
<script type="text/javascript">
/* <![CDATA[ */
CODEEDITOR.instantiate('$id', {'.$config.'}, true);
/* ]]> */
</script>

SCRIPT;
}


/**
 * Replaces textareas with editor instances.
 *
 * @param array $classes  The classes of the textareas that should be replaced.
 * @param mixed $init  Ignored.
 * @global string $onload
 * @return void
 */
function init_codeeditor($classes = array(), $init = FALSE) {
    global $onload;
    
    include_codeeditor();
    if (empty($classes)) {$classes = array('xh-editor');}
    $classes = implode('|', $classes);
    $config = '{mode: \'htmlmixed\', '.codeeditor_config().'}';
    $onload .= 'CODEEDITOR.instantiateByClasses(\''.$classes.'\', '.$config.', true);';
}

?>
